// store for sidebar
import sidebarStore from './sidebarFormStore.js'

/**
 *  mixin extends sidebarForm
 *
 *  @author Björn Hase <me@herr-hase.wtf>
 *  @license http://opensource.org/licenses/MIT The MIT License
 *  @link https://git.node001.net/tiny-components/sidebar-form.git
 *
 */

export default {

    state: {
        open: false,       // if sidebar is open
        isLoading: false,  // if loading is shown
        current: {         // current data of form

        },
        name: undefined
    },

    /**
     *  close current sidebar
     *
     */
    handleClose() {
        this.reset()

        this.state.isOpen = false
        this.update()
    },

    /**
     *  getting css classes for sidebar
     *
     *
     *  @return {String}
     *
     */
    getCssClasses() {
        const classes = [
            'sidebar'
        ]

        if (this.state.isOpen === true) {
            classes.push('sidebar--open')
        }

        return classes.join(' ')
    },

    /**
     *
     *
     *
     */
    onBeforeMount() {
        if (!this.hasOwnProperty('reset')) {
            throw new Error('Sidebar-Form reset-Function is missing')
        }

        if (!this.props.name) {
            throw new Error('Sidebar-Form needs name-attribute for handle open and close-event')
        }

        // adding event for open sidebar
        sidebarStore.on('open.' + this.props.name, (data) =>  {
            if (data) {
                this.state.current = data
            }

            this.state.isOpen = true
            this.update()
        })

        // adding event for open sidebar
        sidebarStore.on('close.' + this.props.name, () =>  {
            this.state.isOpen = false
            this.update()
        })

        // adding event for open sidebar
        sidebarStore.on('close.all', () =>  {
            this.state.isOpen = false
            this.update()
        })

        this.reset()
    }
}
